<div align="center">
  <img alt="featurebox" src="https://github.com/boliqq07/featureboxdocument/blob/master/img.jpg?raw=true">
</div>

[![Python Versions](https://img.shields.io/pypi/pyversions/featurebox.svg)](https://pypi.org/project/featurebox/)
[![Version](https://img.shields.io/github/tag/boliqq07/featurebox.svg)](https://github.com/boliqq07/featurebox/releases/latest)
![pypi Versions](https://badge.fury.io/py/featurebox.svg)


Featurebox
----------------------
Welcome to Featurebox.

Featurebox is a open Python library that implements a comprehensive set of machine learning tools for materials informatics.

This tool contains a symbol regression tool with dimension calculation,
which is aimed at establish expressions with physical limitation.

Featurebox inspired by

  [XenonPy](https://github.com/yoshida-lab/XenonPy),
  [matminer](https://hackingmaterials.github.io/matminer/ ),
  [deap](https://github.com/DEAP/deap),
  [sympy](https://www.sympy.org/en/index.html)

Quick Install
----------------------
```bash
pip install featurebox
```

[Document](https://boliqq07.github.io/featureboxdocument/)
----------------------
The **usage** of this package and **install** deatils are collected in featurebox document.

Turn to [featurebox document](https://boliqq07.github.io/featureboxdocument/) for more details.

License
----------------------
GNU LGPL-3.0 License

Contact
----------------------
Developer: [Boliqq07](986798607@qq.com)




